# django-wikidata-api
[![PyPI](https://img.shields.io/pypi/v/django-wikidata-api?style=flat-square)](https://pypi.org/project/django-wikidata-api/)
[![Travis (.org) branch](https://img.shields.io/travis/kennethsn/django-wikidata-api/master?label=latest%20build&logo=travis&style=flat-square)](https://travis-ci.com/kennethsn/django-wikidata-api)
[![Coveralls github](https://img.shields.io/coveralls/github/kennethsn/django-wikidata-api?style=flat-square)](https://coveralls.io/github/kennethsn/django-wikidata-api?branch=master)
[![PyPI - Status](https://img.shields.io/pypi/status/django-wikidata-api?style=flat-square)](https://pypi.org/project/django-wikidata-api/)


Python Package for interfacing with Wikidata within a Django App


#### Development
![Travis (.org) branch](https://img.shields.io/travis/kennethsn/django-wikidata-api/next-version?label=next%20version&logo=travis&style=flat-square)
![Travis (.org) branch](https://img.shields.io/travis/kennethsn/django-wikidata-api/next-release?label=next%20release&logo=travis&style=flat-square)

_Note: Currently in active development for version 0_
